@@ -5,7 +5,6 @@ use utf8;
 package KUB::Request;
 
 use Xyzzy::Util qw(parse_bool);
-use KUB::Request::Error;
 
 use Xyzzy::Request -self;
 
@@ -28,7 +27,7 @@ field lang => sub {
 		}
 	}
 
-	my $h = lc($self->http('Accept-Language') // '');
+	my $h = lc($self->http('Accept-Language'));
 	$h =~ s/\s//g;
 
 	my $curlang = $supported[0];
@@ -57,8 +56,8 @@ field lang => sub {
 
 sub error {
 	my ($type, $exc, %args) = @_;
-	die $exc if UNIVERSAL::isa($exc, 'Xyzzy::Response');
+	die $exc if ref $exc;
 	warn $exc if $exc;
-	my $doc = new KUB::Request::Error(req => $self, type => $type, args => \%args);
+	my $doc = new KUB::Error(req => $self, type => $type, args => \%args);
 	return $doc->response;
 }
